==> haskell-gnutls-0.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gnutls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnutls
version: 0.2
id: gnutls-0.2-LlTp69RhwSb1bNYRPSnaku
key: gnutls-0.2-LlTp69RhwSb1bNYRPSnaku
license: GPL-3.0-only
maintainer: John Millikin <jmillikin@gmail.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnutls/
synopsis: Bindings for GNU libgnutls
description:
    You almost certainly don'\''t want to depend on this release.
    .
    This is a pre-alpha, almost useless release; its only purpose is to enable
    TLS support in some of my other libraries. More complete bindings for GNU TLS
    will be released at a later date.
category: Network
abi: 24910d45ea734acbdb51d9f1dcd4dc34
exposed: True
exposed-modules:
    Network.Protocol.TLS.GNU
hidden-modules: Network.Protocol.TLS.GNU.ErrorT
                Network.Protocol.TLS.GNU.Foreign
import-dirs: /usr/lib/ghc-8.4.3/site-local/gnutls-0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/gnutls-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/gnutls-0.2
hs-libraries: HSgnutls-0.2-LlTp69RhwSb1bNYRPSnaku
extra-libraries:
    gnutls gnutls
include-dirs: /usr/include/p11-kit-1
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    monads-tf-0.1.0.3-Giaow1Z3bgu7ae1ewXz7xU transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             monads-tf-0.1.0.3-Giaow1Z3bgu7ae1ewXz7xU=186b425acb38e926ddf66c94a3c8e5aa
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-gnutls/html/gnutls.haddock
haddock-html: /usr/share/doc/haskell-gnutls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gnutls-0.2-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gnutls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnutls
version: 0.2
id: gnutls-0.2-HbtZeFWDJ7AYXeVvoZ0l0
key: gnutls-0.2-HbtZeFWDJ7AYXeVvoZ0l0
license: GPL-3.0-only
maintainer: John Millikin <jmillikin@gmail.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnutls/
synopsis: Bindings for GNU libgnutls
description:
    You almost certainly don'\''t want to depend on this release.
    .
    This is a pre-alpha, almost useless release; its only purpose is to enable
    TLS support in some of my other libraries. More complete bindings for GNU TLS
    will be released at a later date.
category: Network
abi: 60c8c34a0ac673ac58ae83214bb6ff2b
exposed: True
exposed-modules:
    Network.Protocol.TLS.GNU
hidden-modules: Network.Protocol.TLS.GNU.ErrorT
                Network.Protocol.TLS.GNU.Foreign
import-dirs: /usr/lib/ghc-8.6.1/site-local/gnutls-0.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/gnutls-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/gnutls-0.2
hs-libraries: HSgnutls-0.2-HbtZeFWDJ7AYXeVvoZ0l0
extra-libraries:
    gnutls gnutls
include-dirs: /usr/include/p11-kit-1
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    monads-tf-0.1.0.3-DFJmu4IXpHk2UzhiB94rsJ transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-gnutls/html/gnutls.haddock
haddock-html: /usr/share/doc/haskell-gnutls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
